# Rasifal

Rasifal is a command-line interface (CLI) tool that fetches and displays daily horoscope in Nepali from the Hamro Patro website.

## Installation

You can install Rasifal directly from PyPI:

```bash
pip install rasifal

```

## Usage

After installation, the tool can be invoked with the `rasifal` command:

```bash
rasifal --sign <your-horoscope-sign>
```

Replace `<your-horoscope-sign>` with your horoscope sign in Nepali. For example, you would use mesh if your horoscope sign is Aries.

### Supported Horoscope Signs

The following horoscope signs are supported:

- Mesh (Aries)
- Brish (Taurus)
- Mithun (Gemini)
- Karkat (Cancer)
- Singha (Leo)
- Kanya (Virgo)
- Tula (Libra)
- Brishchik (Scorpio)
- Dhanu (Sagittarius)
- Makar (Capricorn)
- Kumbha (Aquarius)
- Min (Pisces)


### Acknowledgements

- [hamropatro](https://www.hamropatro.com/rashifal)